@@ -543,6 +543,11 @@ lcmodel_fit <- function(element, temp_mrs, basis_file, opts) {
   #file.copy(coord_f, "~/coord.file", overwrite = TRUE)
   
   coord_res <- read_lcm_coord(coord_f)
+  
+  # change phi1 units from deg / ppm to ms
+  coord_res$res_tab$diags$phi1 <- coord_res$res_tab$diags$phi1 * 
+                                  1000 / 360 / metab$ft * 1e6
+  
   res_tab <- coord_res$res_tab
   fit <- coord_res$fit
   
@@ -609,9 +614,14 @@ read_lcm_coord <- function(coord_f) {
     }
   }
   
-  FWHM <- as.double(strsplit(trimws(line_reader[signals + 6]),"  *")[[1]][3])
-  SNR <- as.double(strsplit(trimws(line_reader[signals + 6]),"  *")[[1]][7])
-  diags <- data.frame(FWHM = FWHM, SNR = SNR)
+  FWHM  <- as.double(strsplit(trimws(line_reader[signals + 6]),"  *")[[1]][3])
+  SNR   <- as.double(strsplit(trimws(line_reader[signals + 6]),"  *")[[1]][7])
+  shift <- as.numeric(gsub("[^0-9.-]", "", line_reader[signals + 7]))
+  phase <- gsub("[^0-9.-]", "", 
+                strsplit(line_reader[signals + 8], "deg")[[1]][1:2])
+  phase <- as.numeric(phase)
+  diags <- data.frame(FWHM = FWHM, SRR = SNR, shift = shift, phase = phase[1],
+                      phi1 = phase[2])
   
   #print(coord_f)  
   # -1 width needed to avoid issues when the metab name is
